@@ -1514,7 +1514,7 @@ void WPG2Parser::handleBitmapData()
 				int count = 1 + (int)readU8();
 				unsigned char* raster_source = ptr - raster_len;
 				for( ; count; --count)
-					for(unsigned r = 0; r < raster_len; r++)
+					for(unsigned long r = 0; r < raster_len; r++)
 						*ptr++ = *raster_source++;
 			}
 
@@ -1524,7 +1524,7 @@ void WPG2Parser::handleBitmapData()
 				// Xor-ing will happen when about to enter next raster
 				// see after the last if down below
 				xor_raster = true;
-				int raster_len = data_size * width;
+				raster_len = data_size * width;
 				next_scanline = ptr + raster_len;
 			}
 
@@ -1564,10 +1564,10 @@ void WPG2Parser::handleBitmapData()
 				xor_raster = false;
 
 				// current raster must be XORed with previous raster
-				int raster_len = data_size * width;
+				raster_len = data_size * width;
 				unsigned char* current = next_scanline - raster_len;
 				unsigned char* previous = current - raster_len;
-				for( int r = 0; r < raster_len; r++)
+				for( unsigned long r = 0; r < raster_len; r++)
 					current[r] ^= previous[r];
 
 			}
@@ -1666,7 +1666,7 @@ void WPG2Parser::handleBitmapData()
 		for (unsigned long y = 0; y < height; y++)
 		for (unsigned long x = 0; x < width; x++, i++)
 		{
-			unsigned short tmpColor = buffer[2*i] | (buffer[2*i+1] << 8);
+			unsigned short tmpColor = (unsigned short)(buffer[2*i] | (buffer[2*i+1] << 8));
 			const libwpg::WPGColor color((tmpColor >> 10) & 0x1f, (tmpColor >> 5) & 0x1f, tmpColor & 0x1f);
 			bitmap.setPixel(x, y, color);
 		}
@@ -1680,7 +1680,7 @@ void WPG2Parser::handleBitmapData()
 		for (unsigned long y = 0; y < height; y++)
 		for (unsigned long x = 0; x < width; x++, i++)
 		{
-			unsigned short tmpColor = buffer[2*i] | (buffer[2*i+1] << 8);
+			unsigned short tmpColor = (unsigned short)(buffer[2*i] | (buffer[2*i+1] << 8));
 			const libwpg::WPGColor color(tmpColor & 0x0f, (tmpColor >> 4) & 0x0f, (tmpColor >> 8) & 0x0f, (tmpColor >> 12) & 0x0f);
 			bitmap.setPixel(x, y, color);
 		}
@@ -1726,7 +1726,7 @@ void WPG2Parser::handleBitmapData()
 	}
 	
 	
-
+#ifdef DEBUG
 	// debugging only
 	if(buffer && 0)
 	{
@@ -1737,6 +1737,7 @@ void WPG2Parser::handleBitmapData()
 			WPG_DEBUG_MSG((" pixel at %li, %li: %3d %3d %3d\n", x, y, color.red, color.green, color.blue));
 		}
 	}
+#endif
 
 	// discard
 	delete [] buffer;
